@@ -24,7 +24,7 @@ ZimView::ZimView(TabBar *tabBar, QWidget *parent)
                     return;
                 auto zoomFactor = mp_webView->zoomFactor();
                 zoomFactor += 0.1;
-                zoomFactor = max(min(zoomFactor, 5.0), 0.25);
+                zoomFactor = std::max(std::min(zoomFactor, 5.0), 0.25);
                 mp_webView->setZoomFactor(zoomFactor);
                 auto key = mp_webView->zimId() + "/zoomFactor";
                 KiwixApp::instance()->getSettingsManager()->setSettings(key, zoomFactor);
@@ -35,7 +35,7 @@ ZimView::ZimView(TabBar *tabBar, QWidget *parent)
                     return;
                 auto zoomFactor = mp_webView->zoomFactor();
                 zoomFactor -= 0.1;
-                zoomFactor = max(min(zoomFactor, 5.0), 0.25);
+                zoomFactor = std::max(std::min(zoomFactor, 5.0), 0.25);
                 mp_webView->setZoomFactor(zoomFactor);
                 auto key = mp_webView->zimId() + "/zoomFactor";
                 KiwixApp::instance()->getSettingsManager()->setSettings(key, zoomFactor);
@@ -62,18 +62,12 @@ ZimView::ZimView(TabBar *tabBar, QWidget *parent)
             [=](const QIcon& icon) { mp_tabBar->setIconOf(icon, this); });
 
     connect(mp_webView->page()->action(QWebEnginePage::Back), &QAction::changed,
-            [=]() {
-                if (mp_tabBar->currentZimView() != this) {
-                    return;
-                }
-                emit mp_tabBar->webActionEnabledChanged(QWebEnginePage::Back, mp_webView->isWebActionEnabled(QWebEnginePage::Back));
+            [this]() {
+                emit webActionEnabledChanged(QWebEnginePage::Back, this->mp_webView->isWebActionEnabled(QWebEnginePage::Back));
             });
     connect(mp_webView->page()->action(QWebEnginePage::Forward), &QAction::changed,
-            [=]() {
-                if (mp_tabBar->currentZimView() != this) {
-                    return;
-                }
-                emit mp_tabBar->webActionEnabledChanged(QWebEnginePage::Forward, mp_webView->isWebActionEnabled(QWebEnginePage::Forward));
+            [this]() {
+                emit webActionEnabledChanged(QWebEnginePage::Forward, this->mp_webView->isWebActionEnabled(QWebEnginePage::Forward));
             });
     connect(mp_webView->page(), &QWebEnginePage::linkHovered, this,
             [=](const QString& url) {
